import os
import sys
import subprocess
import click

@click.command()
@click.option('--zip', 'zip_file', required=True, help='Path to the zip file.')
@click.option('--pass', 'password_list', required=True, help='Path to the password list file.')
@click.option('--unzip', is_flag=True, help='Automatically unzip after finding the password.')
@click.option('--save', 'save_file', help='Save the found password to a file.')
@click.option('--silent', is_flag=True, help='Silent mode, only display the found password.')
def cli(zip_file, password_list, unzip, save_file, silent):
    if not sys.platform.startswith('linux'):
        print("This tool only works on Linux.")
        sys.exit(1)

    script_path = os.path.join(os.path.dirname(__file__), 'ziplip.sh')  # Corrected the script path

    command = ['bash', script_path, '--zip', zip_file, '--pass', password_list]  # Corrected the command construction
    
    if unzip:
        command.append('--unzip')
    if save_file:
        command.extend(['--save', save_file])
    if silent:
        command.append('--silent')

    subprocess.run(command)

if __name__ == "__main__":
    cli()



from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as readme_file:
    long_description = readme_file.read()

setup(
    name='ziplip',
    version='1.0.9',
    description='ziplip - Zip File Password Brute Force Tool',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://mrfidal.in/cyber-security/ziplip',
    author='Fidal',
    author_email='mrfidal@proton.me',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.11',
        'Topic :: Security',
    ],
    keywords='zip file, brute force, enumeration, scanning, mrfidal, cyber security',
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'ziplip': ['ziplip.sh'],
    },
    install_requires=[
        'requests',
        'click', 
    ],
    entry_points={
        'console_scripts': [
            'ziplip=ziplip.cli:cli', 
        ],
    },
)
